@@ -199,7 +199,7 @@ void GtkConfig::setEnableAnimations() const
 
 void GtkConfig::setGlobalScale() const
 {
-    const int scaleFactor = configValueProvider->x11GlobalScaleFactor();
+    const unsigned scaleFactor = configValueProvider->x11GlobalScaleFactor();
     XSettingsEditor::setValue(QStringLiteral("Gdk/WindowScalingFactor"), scaleFactor);
     GSettingsEditor::setValue("scaling-factor", scaleFactor); // For IntelliJ IDEA
 }
